import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

//giving iris dataset as sourcelink
const csvUrl ='https://gist.githubusercontent.com/Snapika/1f7a0d1beb5de404f05839908e1d3378/raw/7b73072d9f77a30a0aecde0b9de588b112bdffc3/irisdataset.csv';
//parsing the strings to numbers
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);
//LOAD THE DATA
const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = 'Species';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'setosa':
              return 'blue';
            case 'versicolor':
              return 'orange';
            default:
              return 'red';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Adjusting margins
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
 // genarting plot from the values above 
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, $150)`);






svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];

  svg.selectAll('text').remove();
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length'*/
		
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","normal")
          .style("stroke","black")
          .text(colorLabel);

   
// giving title
svg.append("text").attr("x", 450).attr("y", 20).text("Iris Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Assigning colors to three species
svg.append("text").attr("x", 150).attr("y", 70).text("Setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Virginica").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","normal")
        	.style("font-weight","bold")
        	.text("Sepal Length")
    			
    		
    
    
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "orange")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")
   // petal_width on x-axis
    if(i % columns.length==0) 
    svg
          
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
    			//.attr("id","the_SVG_ID")
        	.style("text-anchor", "middle")
        	.style("font-style","normal")
        	.style("font-weight","bold")
      		.text("Petal Width")
    
     // sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	//.select("#the_SVG_ID").remove()
          .append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","normal")
        	.style("font-weight","bold")
      		//.text("Sepal Width")
    			;
     //  petal_length on x-axis
    else if(i % columns.length==2) 
    svg		
          .append("text")
    			.selectAll('text').remove()
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","normal")
        	.style("font-weight","bold")
      		.text("Petal Length");
     //  sepal_length on x-axis
       else 
    svg
      		.append("text")
    			.selectAll('text').remove()
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style", "normal")
        	.style("font-weight","bold")
					.text("Sepal Length");
    
    i++;
  }, 3000);// giving time period as 3 seconds
};
main();



